@@ -1,7 +1,8 @@
 from .event import Event
+from .detail import Detail
 from .geochat import GeoChat
 from .point import Point
 from .takuser import TAKUser, TAKDevice
 from .teams import Teams
 
-__all__ = ['Event', 'GeoChat', 'Point', 'TAKUser', 'TAKDevice', 'Teams']
+__all__ = ['Event', 'Detail', 'GeoChat', 'Point', 'TAKUser', 'TAKDevice', 'Teams']
